"use strict";

var helpers = require("../../helpers/helpers");

exports["Brazil/East"] = {

	"guess:by:offset" : helpers.makeTestGuess("Brazil/East", { offset: true, expect: "America/Sao_Paulo" }),

	"guess:by:abbr" : helpers.makeTestGuess("Brazil/East", { abbr: true, expect: "America/Sao_Paulo" }),

	"1914" : helpers.makeTestYear("Brazil/East", [
		["1914-01-01T03:06:27+00:00", "23:59:59", "LMT", 11188 / 60],
		["1914-01-01T03:06:28+00:00", "00:06:28", "-03", 180]
	]),

	"1931" : helpers.makeTestYear("Brazil/East", [
		["1931-10-03T13:59:59+00:00", "10:59:59", "-03", 180],
		["1931-10-03T14:00:00+00:00", "12:00:00", "-02", 120]
	]),

	"1932" : helpers.makeTestYear("Brazil/East", [
		["1932-04-01T01:59:59+00:00", "23:59:59", "-02", 120],
		["1932-04-01T02:00:00+00:00", "23:00:00", "-03", 180],
		["1932-10-03T02:59:59+00:00", "23:59:59", "-03", 180],
		["1932-10-03T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1933" : helpers.makeTestYear("Brazil/East", [
		["1933-04-01T01:59:59+00:00", "23:59:59", "-02", 120],
		["1933-04-01T02:00:00+00:00", "23:00:00", "-03", 180]
	]),

	"1949" : helpers.makeTestYear("Brazil/East", [
		["1949-12-01T02:59:59+00:00", "23:59:59", "-03", 180],
		["1949-12-01T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1950" : helpers.makeTestYear("Brazil/East", [
		["1950-04-16T02:59:59+00:00", "00:59:59", "-02", 120],
		["1950-04-16T03:00:00+00:00", "00:00:00", "-03", 180],
		["1950-12-01T02:59:59+00:00", "23:59:59", "-03", 180],
		["1950-12-01T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1951" : helpers.makeTestYear("Brazil/East", [
		["1951-04-01T01:59:59+00:00", "23:59:59", "-02", 120],
		["1951-04-01T02:00:00+00:00", "23:00:00", "-03", 180],
		["1951-12-01T02:59:59+00:00", "23:59:59", "-03", 180],
		["1951-12-01T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1952" : helpers.makeTestYear("Brazil/East", [
		["1952-04-01T01:59:59+00:00", "23:59:59", "-02", 120],
		["1952-04-01T02:00:00+00:00", "23:00:00", "-03", 180],
		["1952-12-01T02:59:59+00:00", "23:59:59", "-03", 180],
		["1952-12-01T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1953" : helpers.makeTestYear("Brazil/East", [
		["1953-03-01T01:59:59+00:00", "23:59:59", "-02", 120],
		["1953-03-01T02:00:00+00:00", "23:00:00", "-03", 180]
	]),

	"1963" : helpers.makeTestYear("Brazil/East", [
		["1963-10-23T02:59:59+00:00", "23:59:59", "-03", 180],
		["1963-10-23T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1964" : helpers.makeTestYear("Brazil/East", [
		["1964-03-01T01:59:59+00:00", "23:59:59", "-02", 120],
		["1964-03-01T02:00:00+00:00", "23:00:00", "-03", 180]
	]),

	"1965" : helpers.makeTestYear("Brazil/East", [
		["1965-01-31T02:59:59+00:00", "23:59:59", "-03", 180],
		["1965-01-31T03:00:00+00:00", "01:00:00", "-02", 120],
		["1965-03-31T01:59:59+00:00", "23:59:59", "-02", 120],
		["1965-03-31T02:00:00+00:00", "23:00:00", "-03", 180],
		["1965-12-01T02:59:59+00:00", "23:59:59", "-03", 180],
		["1965-12-01T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1966" : helpers.makeTestYear("Brazil/East", [
		["1966-03-01T01:59:59+00:00", "23:59:59", "-02", 120],
		["1966-03-01T02:00:00+00:00", "23:00:00", "-03", 180],
		["1966-11-01T02:59:59+00:00", "23:59:59", "-03", 180],
		["1966-11-01T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1967" : helpers.makeTestYear("Brazil/East", [
		["1967-03-01T01:59:59+00:00", "23:59:59", "-02", 120],
		["1967-03-01T02:00:00+00:00", "23:00:00", "-03", 180],
		["1967-11-01T02:59:59+00:00", "23:59:59", "-03", 180],
		["1967-11-01T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1968" : helpers.makeTestYear("Brazil/East", [
		["1968-03-01T01:59:59+00:00", "23:59:59", "-02", 120],
		["1968-03-01T02:00:00+00:00", "23:00:00", "-03", 180]
	]),

	"1985" : helpers.makeTestYear("Brazil/East", [
		["1985-11-02T02:59:59+00:00", "23:59:59", "-03", 180],
		["1985-11-02T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1986" : helpers.makeTestYear("Brazil/East", [
		["1986-03-15T01:59:59+00:00", "23:59:59", "-02", 120],
		["1986-03-15T02:00:00+00:00", "23:00:00", "-03", 180],
		["1986-10-25T02:59:59+00:00", "23:59:59", "-03", 180],
		["1986-10-25T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1987" : helpers.makeTestYear("Brazil/East", [
		["1987-02-14T01:59:59+00:00", "23:59:59", "-02", 120],
		["1987-02-14T02:00:00+00:00", "23:00:00", "-03", 180],
		["1987-10-25T02:59:59+00:00", "23:59:59", "-03", 180],
		["1987-10-25T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1988" : helpers.makeTestYear("Brazil/East", [
		["1988-02-07T01:59:59+00:00", "23:59:59", "-02", 120],
		["1988-02-07T02:00:00+00:00", "23:00:00", "-03", 180],
		["1988-10-16T02:59:59+00:00", "23:59:59", "-03", 180],
		["1988-10-16T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1989" : helpers.makeTestYear("Brazil/East", [
		["1989-01-29T01:59:59+00:00", "23:59:59", "-02", 120],
		["1989-01-29T02:00:00+00:00", "23:00:00", "-03", 180],
		["1989-10-15T02:59:59+00:00", "23:59:59", "-03", 180],
		["1989-10-15T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1990" : helpers.makeTestYear("Brazil/East", [
		["1990-02-11T01:59:59+00:00", "23:59:59", "-02", 120],
		["1990-02-11T02:00:00+00:00", "23:00:00", "-03", 180],
		["1990-10-21T02:59:59+00:00", "23:59:59", "-03", 180],
		["1990-10-21T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1991" : helpers.makeTestYear("Brazil/East", [
		["1991-02-17T01:59:59+00:00", "23:59:59", "-02", 120],
		["1991-02-17T02:00:00+00:00", "23:00:00", "-03", 180],
		["1991-10-20T02:59:59+00:00", "23:59:59", "-03", 180],
		["1991-10-20T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1992" : helpers.makeTestYear("Brazil/East", [
		["1992-02-09T01:59:59+00:00", "23:59:59", "-02", 120],
		["1992-02-09T02:00:00+00:00", "23:00:00", "-03", 180],
		["1992-10-25T02:59:59+00:00", "23:59:59", "-03", 180],
		["1992-10-25T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1993" : helpers.makeTestYear("Brazil/East", [
		["1993-01-31T01:59:59+00:00", "23:59:59", "-02", 120],
		["1993-01-31T02:00:00+00:00", "23:00:00", "-03", 180],
		["1993-10-17T02:59:59+00:00", "23:59:59", "-03", 180],
		["1993-10-17T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1994" : helpers.makeTestYear("Brazil/East", [
		["1994-02-20T01:59:59+00:00", "23:59:59", "-02", 120],
		["1994-02-20T02:00:00+00:00", "23:00:00", "-03", 180],
		["1994-10-16T02:59:59+00:00", "23:59:59", "-03", 180],
		["1994-10-16T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1995" : helpers.makeTestYear("Brazil/East", [
		["1995-02-19T01:59:59+00:00", "23:59:59", "-02", 120],
		["1995-02-19T02:00:00+00:00", "23:00:00", "-03", 180],
		["1995-10-15T02:59:59+00:00", "23:59:59", "-03", 180],
		["1995-10-15T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1996" : helpers.makeTestYear("Brazil/East", [
		["1996-02-11T01:59:59+00:00", "23:59:59", "-02", 120],
		["1996-02-11T02:00:00+00:00", "23:00:00", "-03", 180],
		["1996-10-06T02:59:59+00:00", "23:59:59", "-03", 180],
		["1996-10-06T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1997" : helpers.makeTestYear("Brazil/East", [
		["1997-02-16T01:59:59+00:00", "23:59:59", "-02", 120],
		["1997-02-16T02:00:00+00:00", "23:00:00", "-03", 180],
		["1997-10-06T02:59:59+00:00", "23:59:59", "-03", 180],
		["1997-10-06T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1998" : helpers.makeTestYear("Brazil/East", [
		["1998-03-01T01:59:59+00:00", "23:59:59", "-02", 120],
		["1998-03-01T02:00:00+00:00", "23:00:00", "-03", 180],
		["1998-10-11T02:59:59+00:00", "23:59:59", "-03", 180],
		["1998-10-11T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"1999" : helpers.makeTestYear("Brazil/East", [
		["1999-02-21T01:59:59+00:00", "23:59:59", "-02", 120],
		["1999-02-21T02:00:00+00:00", "23:00:00", "-03", 180],
		["1999-10-03T02:59:59+00:00", "23:59:59", "-03", 180],
		["1999-10-03T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2000" : helpers.makeTestYear("Brazil/East", [
		["2000-02-27T01:59:59+00:00", "23:59:59", "-02", 120],
		["2000-02-27T02:00:00+00:00", "23:00:00", "-03", 180],
		["2000-10-08T02:59:59+00:00", "23:59:59", "-03", 180],
		["2000-10-08T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2001" : helpers.makeTestYear("Brazil/East", [
		["2001-02-18T01:59:59+00:00", "23:59:59", "-02", 120],
		["2001-02-18T02:00:00+00:00", "23:00:00", "-03", 180],
		["2001-10-14T02:59:59+00:00", "23:59:59", "-03", 180],
		["2001-10-14T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2002" : helpers.makeTestYear("Brazil/East", [
		["2002-02-17T01:59:59+00:00", "23:59:59", "-02", 120],
		["2002-02-17T02:00:00+00:00", "23:00:00", "-03", 180],
		["2002-11-03T02:59:59+00:00", "23:59:59", "-03", 180],
		["2002-11-03T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2003" : helpers.makeTestYear("Brazil/East", [
		["2003-02-16T01:59:59+00:00", "23:59:59", "-02", 120],
		["2003-02-16T02:00:00+00:00", "23:00:00", "-03", 180],
		["2003-10-19T02:59:59+00:00", "23:59:59", "-03", 180],
		["2003-10-19T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2004" : helpers.makeTestYear("Brazil/East", [
		["2004-02-15T01:59:59+00:00", "23:59:59", "-02", 120],
		["2004-02-15T02:00:00+00:00", "23:00:00", "-03", 180],
		["2004-11-02T02:59:59+00:00", "23:59:59", "-03", 180],
		["2004-11-02T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2005" : helpers.makeTestYear("Brazil/East", [
		["2005-02-20T01:59:59+00:00", "23:59:59", "-02", 120],
		["2005-02-20T02:00:00+00:00", "23:00:00", "-03", 180],
		["2005-10-16T02:59:59+00:00", "23:59:59", "-03", 180],
		["2005-10-16T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2006" : helpers.makeTestYear("Brazil/East", [
		["2006-02-19T01:59:59+00:00", "23:59:59", "-02", 120],
		["2006-02-19T02:00:00+00:00", "23:00:00", "-03", 180],
		["2006-11-05T02:59:59+00:00", "23:59:59", "-03", 180],
		["2006-11-05T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2007" : helpers.makeTestYear("Brazil/East", [
		["2007-02-25T01:59:59+00:00", "23:59:59", "-02", 120],
		["2007-02-25T02:00:00+00:00", "23:00:00", "-03", 180],
		["2007-10-14T02:59:59+00:00", "23:59:59", "-03", 180],
		["2007-10-14T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2008" : helpers.makeTestYear("Brazil/East", [
		["2008-02-17T01:59:59+00:00", "23:59:59", "-02", 120],
		["2008-02-17T02:00:00+00:00", "23:00:00", "-03", 180],
		["2008-10-19T02:59:59+00:00", "23:59:59", "-03", 180],
		["2008-10-19T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2009" : helpers.makeTestYear("Brazil/East", [
		["2009-02-15T01:59:59+00:00", "23:59:59", "-02", 120],
		["2009-02-15T02:00:00+00:00", "23:00:00", "-03", 180],
		["2009-10-18T02:59:59+00:00", "23:59:59", "-03", 180],
		["2009-10-18T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2010" : helpers.makeTestYear("Brazil/East", [
		["2010-02-21T01:59:59+00:00", "23:59:59", "-02", 120],
		["2010-02-21T02:00:00+00:00", "23:00:00", "-03", 180],
		["2010-10-17T02:59:59+00:00", "23:59:59", "-03", 180],
		["2010-10-17T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2011" : helpers.makeTestYear("Brazil/East", [
		["2011-02-20T01:59:59+00:00", "23:59:59", "-02", 120],
		["2011-02-20T02:00:00+00:00", "23:00:00", "-03", 180],
		["2011-10-16T02:59:59+00:00", "23:59:59", "-03", 180],
		["2011-10-16T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2012" : helpers.makeTestYear("Brazil/East", [
		["2012-02-26T01:59:59+00:00", "23:59:59", "-02", 120],
		["2012-02-26T02:00:00+00:00", "23:00:00", "-03", 180],
		["2012-10-21T02:59:59+00:00", "23:59:59", "-03", 180],
		["2012-10-21T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2013" : helpers.makeTestYear("Brazil/East", [
		["2013-02-17T01:59:59+00:00", "23:59:59", "-02", 120],
		["2013-02-17T02:00:00+00:00", "23:00:00", "-03", 180],
		["2013-10-20T02:59:59+00:00", "23:59:59", "-03", 180],
		["2013-10-20T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2014" : helpers.makeTestYear("Brazil/East", [
		["2014-02-16T01:59:59+00:00", "23:59:59", "-02", 120],
		["2014-02-16T02:00:00+00:00", "23:00:00", "-03", 180],
		["2014-10-19T02:59:59+00:00", "23:59:59", "-03", 180],
		["2014-10-19T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2015" : helpers.makeTestYear("Brazil/East", [
		["2015-02-22T01:59:59+00:00", "23:59:59", "-02", 120],
		["2015-02-22T02:00:00+00:00", "23:00:00", "-03", 180],
		["2015-10-18T02:59:59+00:00", "23:59:59", "-03", 180],
		["2015-10-18T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2016" : helpers.makeTestYear("Brazil/East", [
		["2016-02-21T01:59:59+00:00", "23:59:59", "-02", 120],
		["2016-02-21T02:00:00+00:00", "23:00:00", "-03", 180],
		["2016-10-16T02:59:59+00:00", "23:59:59", "-03", 180],
		["2016-10-16T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2017" : helpers.makeTestYear("Brazil/East", [
		["2017-02-19T01:59:59+00:00", "23:59:59", "-02", 120],
		["2017-02-19T02:00:00+00:00", "23:00:00", "-03", 180],
		["2017-10-15T02:59:59+00:00", "23:59:59", "-03", 180],
		["2017-10-15T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2018" : helpers.makeTestYear("Brazil/East", [
		["2018-02-18T01:59:59+00:00", "23:59:59", "-02", 120],
		["2018-02-18T02:00:00+00:00", "23:00:00", "-03", 180],
		["2018-11-04T02:59:59+00:00", "23:59:59", "-03", 180],
		["2018-11-04T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2019" : helpers.makeTestYear("Brazil/East", [
		["2019-02-17T01:59:59+00:00", "23:59:59", "-02", 120],
		["2019-02-17T02:00:00+00:00", "23:00:00", "-03", 180],
		["2019-11-03T02:59:59+00:00", "23:59:59", "-03", 180],
		["2019-11-03T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2020" : helpers.makeTestYear("Brazil/East", [
		["2020-02-16T01:59:59+00:00", "23:59:59", "-02", 120],
		["2020-02-16T02:00:00+00:00", "23:00:00", "-03", 180],
		["2020-11-01T02:59:59+00:00", "23:59:59", "-03", 180],
		["2020-11-01T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2021" : helpers.makeTestYear("Brazil/East", [
		["2021-02-21T01:59:59+00:00", "23:59:59", "-02", 120],
		["2021-02-21T02:00:00+00:00", "23:00:00", "-03", 180],
		["2021-11-07T02:59:59+00:00", "23:59:59", "-03", 180],
		["2021-11-07T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2022" : helpers.makeTestYear("Brazil/East", [
		["2022-02-20T01:59:59+00:00", "23:59:59", "-02", 120],
		["2022-02-20T02:00:00+00:00", "23:00:00", "-03", 180],
		["2022-11-06T02:59:59+00:00", "23:59:59", "-03", 180],
		["2022-11-06T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2023" : helpers.makeTestYear("Brazil/East", [
		["2023-02-26T01:59:59+00:00", "23:59:59", "-02", 120],
		["2023-02-26T02:00:00+00:00", "23:00:00", "-03", 180],
		["2023-11-05T02:59:59+00:00", "23:59:59", "-03", 180],
		["2023-11-05T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2024" : helpers.makeTestYear("Brazil/East", [
		["2024-02-18T01:59:59+00:00", "23:59:59", "-02", 120],
		["2024-02-18T02:00:00+00:00", "23:00:00", "-03", 180],
		["2024-11-03T02:59:59+00:00", "23:59:59", "-03", 180],
		["2024-11-03T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2025" : helpers.makeTestYear("Brazil/East", [
		["2025-02-16T01:59:59+00:00", "23:59:59", "-02", 120],
		["2025-02-16T02:00:00+00:00", "23:00:00", "-03", 180],
		["2025-11-02T02:59:59+00:00", "23:59:59", "-03", 180],
		["2025-11-02T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2026" : helpers.makeTestYear("Brazil/East", [
		["2026-02-22T01:59:59+00:00", "23:59:59", "-02", 120],
		["2026-02-22T02:00:00+00:00", "23:00:00", "-03", 180],
		["2026-11-01T02:59:59+00:00", "23:59:59", "-03", 180],
		["2026-11-01T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2027" : helpers.makeTestYear("Brazil/East", [
		["2027-02-21T01:59:59+00:00", "23:59:59", "-02", 120],
		["2027-02-21T02:00:00+00:00", "23:00:00", "-03", 180],
		["2027-11-07T02:59:59+00:00", "23:59:59", "-03", 180],
		["2027-11-07T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2028" : helpers.makeTestYear("Brazil/East", [
		["2028-02-20T01:59:59+00:00", "23:59:59", "-02", 120],
		["2028-02-20T02:00:00+00:00", "23:00:00", "-03", 180],
		["2028-11-05T02:59:59+00:00", "23:59:59", "-03", 180],
		["2028-11-05T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2029" : helpers.makeTestYear("Brazil/East", [
		["2029-02-18T01:59:59+00:00", "23:59:59", "-02", 120],
		["2029-02-18T02:00:00+00:00", "23:00:00", "-03", 180],
		["2029-11-04T02:59:59+00:00", "23:59:59", "-03", 180],
		["2029-11-04T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2030" : helpers.makeTestYear("Brazil/East", [
		["2030-02-17T01:59:59+00:00", "23:59:59", "-02", 120],
		["2030-02-17T02:00:00+00:00", "23:00:00", "-03", 180],
		["2030-11-03T02:59:59+00:00", "23:59:59", "-03", 180],
		["2030-11-03T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2031" : helpers.makeTestYear("Brazil/East", [
		["2031-02-16T01:59:59+00:00", "23:59:59", "-02", 120],
		["2031-02-16T02:00:00+00:00", "23:00:00", "-03", 180],
		["2031-11-02T02:59:59+00:00", "23:59:59", "-03", 180],
		["2031-11-02T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2032" : helpers.makeTestYear("Brazil/East", [
		["2032-02-15T01:59:59+00:00", "23:59:59", "-02", 120],
		["2032-02-15T02:00:00+00:00", "23:00:00", "-03", 180],
		["2032-11-07T02:59:59+00:00", "23:59:59", "-03", 180],
		["2032-11-07T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2033" : helpers.makeTestYear("Brazil/East", [
		["2033-02-20T01:59:59+00:00", "23:59:59", "-02", 120],
		["2033-02-20T02:00:00+00:00", "23:00:00", "-03", 180],
		["2033-11-06T02:59:59+00:00", "23:59:59", "-03", 180],
		["2033-11-06T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2034" : helpers.makeTestYear("Brazil/East", [
		["2034-02-26T01:59:59+00:00", "23:59:59", "-02", 120],
		["2034-02-26T02:00:00+00:00", "23:00:00", "-03", 180],
		["2034-11-05T02:59:59+00:00", "23:59:59", "-03", 180],
		["2034-11-05T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2035" : helpers.makeTestYear("Brazil/East", [
		["2035-02-18T01:59:59+00:00", "23:59:59", "-02", 120],
		["2035-02-18T02:00:00+00:00", "23:00:00", "-03", 180],
		["2035-11-04T02:59:59+00:00", "23:59:59", "-03", 180],
		["2035-11-04T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2036" : helpers.makeTestYear("Brazil/East", [
		["2036-02-17T01:59:59+00:00", "23:59:59", "-02", 120],
		["2036-02-17T02:00:00+00:00", "23:00:00", "-03", 180],
		["2036-11-02T02:59:59+00:00", "23:59:59", "-03", 180],
		["2036-11-02T03:00:00+00:00", "01:00:00", "-02", 120]
	]),

	"2037" : helpers.makeTestYear("Brazil/East", [
		["2037-02-22T01:59:59+00:00", "23:59:59", "-02", 120],
		["2037-02-22T02:00:00+00:00", "23:00:00", "-03", 180],
		["2037-11-01T02:59:59+00:00", "23:59:59", "-03", 180],
		["2037-11-01T03:00:00+00:00", "01:00:00", "-02", 120]
	])
};